---
author: Jeremy Kidwell
date: "2019-02-19"
#layout: post
slug: environmental_writing
status: publish
title: Catch-up Christian environmentalism and public policy
categories:
- environmental attitudes
- eco-congregation Scotland
---

For the past two years, I've been synthesising and presenting my research into Christian environmentalism at a variety of fora. This has finally coalesced in a series of publications recently, so it seemed like a good time to gather some of these strands together in case anyone might be interested in the big picture and how all these bits fit together. It's worth noting that quite a lot of this work is still coming together, so there are several publications in draft and which I've presented which won't be out for a while yet officially. I'll also highlight a few features that are still WIP.

### First, the publications and a bit of summary:

- Christopher D. Ives, Jeremy H. Kidwell, [“Religion and social values for sustainability”](https://jeremykidwell.info/publications/2019_religion_social_values/) in *Sustainability Science*, vol. n, iss. n, Feb 2019.

*You should read the whole study (link above!) but here's a quick summary that might be helpful if you're not familiar with the scholarly field we're interacting with:*

I've been delighted to take up a new research collaboration with Christopher D. Ives who has a tremendous level of experience within environmental sciences, particularly environmental management, but also an awareness of human geography. Chris and I are trying to identify what features are unique about religious environmentalism – particularly Christian environmentalism with which we're both most familiar – and then communicate that to a broader policy-focussed (and secular) scholarly audience across environmental and political science and probably also environmental economics. There is a lot of very important translation work that needs to be done - in many cases, neither policymakers, social scientists or Christians at the grassroots themselves have a clear sense of how their work is unique in comparison to other kinds of environmental movements. In this article, we survey the field of environmental values, where economists and environmental scientists have been attempting for several decades now, to crystallise how we might ascribe value to the natural world. You can see this in the development of an [ecosystem services](https://en.wikipedia.org/wiki/Ecosystem_services) model which crystallised in 2006 in the Millennium Ecosystem Assessment. This kind of model has proven very helpful in public policy circles in affirming the hidden and potentially quantifiable value of seemingly extravagant measures such as ecosystem conservation. However, it ends up being, in practice, quite difficult to make all the intangible aspects into tangible and quantifiable measurements. Environmental scientists are well aware of this and have been working to develop ever more sophisticated versions of value models, resulting in a recent boom in "cultural values" and "social values" and by extension, we argue, explicitly religious values. A blunt way to put this is that "theology matters" and "churches matter" when it comes to caring for the earth. We highlight a few specific ways this is the case in our article, particularly in providing persons and communities with a matrix for the upholding of altruistic values, which seems to be increasingly difficult in the contemporary public sphere, so all the more important when we can find places where this is the case. However, as I've already suggested, it's not just a matter of distilling all the components of theological understanding into a simplistic model. As we argue, "values are embedded" and not easily extracted from their contexts. Further, the mobilisation of Christian belief is also complex. Popular stereotypes suggest that when Christian leaders put out a public statement (whether this is the Pope or Billy Graham) their people just fall into line obediently. We take the example of Pope Francis' recent encyclical Laudato Sí to highlight ways that top-down dissemination doesn't always work in predictable ways, particularly in Christian church hierarchies. Finally, we highlight ways that theological worldviews are complex and layered. Our identities as people of faith draw on a number of different sources. We argue that if researchers are to engage with people of faith in a meaningful way, their methods will need to work on such a level which can capture the full web of values within a worldview and represent the significance of theology in the midst of it.

- Jeremy H. Kidwell, Franklin Ginn, Michael Northcott, Elizabeth Bomberg and Alice Hague, [“Christian climate care: Slow change, modesty and eco-theo-citizenship”](https://jeremykidwell.info/publications/2018_geo/) in Geo, vol. 5, iss. 2, Sep 2018.

This article is the first major output from a massive study, which involved interviews with ministers, lay-leaders, and activists at 44 different Eco-Congregation churches across the UK, documentary analysis of hundreds of Eco-Congregation applications, and much more which we'll be sharing in other research outputs in the next few years. It's the first study of this scope of Christian environmentalism in the UK. In the broader scholarly study of environmentalism, one key question relates to how action and values relate to one another. That is, do we have a value and then act on it OR is it through ongoing actions that our values are formed and reinforced? We agree with a host of geographers and sociologists who essentially suggest that this is a paradoxical question which has no answer. Actions and values reinforce one another across the life of an individual person (and community) and it is impossible to ultimately sort out which of these two started everything off for a particular person. This is a salient concern for the study of Christian environmentalism, as policymakers are ultimately very curious to know whether being part of a church community (=practices?) or holding some kind of theological belief (=value?) have some sort of measurable impact on whether you will make changes to your lifestyle etc. in response to a problem like climate change. It's also worth noting, that social psychologists have observed that the relationship between holding a value and acting upon that value-orientation is complex as well. Many people hold values (sometimes defending them quite fiercely) without taking actions which enshrine those values. Given all these paradoxes, we wanted to see if we could provide a more faithful representation of what is going on in Eco-Congregations in Scotland, and perhaps find a description which might map onto Christian environmentalism more broadly.

What we ultimately argue is that Christian belief and Christian community stand in both resonance and tension with wider environmental identities. We call this Eco-Theo-Citizenship, in order to highlight the way that people in Eco-Congregations might participate in climate change mitigation to (1) just be a good citizen (like recycling) or (2) because of their theological formation (shown in concern for justice or stewardship). But these two overlap with one another in a kind of reinforcing spiral, so as I've already noted above, they are hard to disentangle. This also works on the level of community, whether a person is thinking of their local church or the worldwide confederation of Christian believers. Christians are often negotiating their identity as a global (good) citizen, but also holding onto a set of values which are "not of this world". This is a tension, we think, which is being negotiated in an ongoing way by Christian eco-communities.

We go on to suggest that if one were to take this model seriously, then it is possible to observe some consistent features about the types of environmentalism being expressed by people in Eco-Congregations. For the sake of this very brief article we shared two features which we imagined might be particularly relevant to the public policy community (there are many more!):

1. "Eco-Congregations tend to focus on *process and structure* as much as environmental *actions*" (p.12). It can be easy to see this as a problem, i.e. that an Eco-Congregation group might get terribly bogged down in committee politics on relatively small issues. And we met many Christians who indicated that they felt a bit self-conscious about how slowly their work got on. However, looking to wider anthropological studies of activist groups, we note that a focus on process is actually the underpinning foundation for stable and meaningful community, which then provides the basis for long-term and potentially transformative action. In this era of individualism and anomie, such an orientation on the small community can be quite countercultural and potentially serve to reinforce community resilience and cohesion. There's also a point we didn't have space to explore fully here that (we think) the most meaningful division among Eco-Congregation groups is not by denomination, but between those churches which are structured (Church of Scotland, Roman Catholic, and other mainline protestant groups) and those which are not (Baptist chuches, evanglical churches, quakers and unitarians). In this case, churches with beurocracies are functionally similar to those which have hierarchies. Taking on these two as separate frames is likely a good choice for high-level organisations trying to engage with Eco-Congregations/Churches in a meaningful way.

2. Environmentally active Christians are generally modest about their achievements and unlikely to champion their successes. They often see other secular groups as more efficacious even when they aren't. In an age when community level groups are often supported through grant funding, this can have a particular impact on their ability to secure resources, or to have the ambition to take on big projects. Similarly, when churches do support a big project, they often hand it off to the wider community for long-term stewardship. We found examples of dozens of large scale eco-projects which were discretely built-up by an Eco-Congregation group. There is a related impact on public perceptions of Christian environmentalism. Christians do often have a visible focus on eco-projects related to their buildings (new boilers, energy production, windows, lighting, etc.) and leave their wider community-facing achievements unclaimed. There's another strand of research here which remains implicit in this article, but which I'll be taking up in later work. This is, that Christians involved in Eco-Congregations are also often involved in a whole range of other community groups: from Greenpeace, Friends of the Earth and the Green Party to Scout Groups, Fair Trade and Transition Towns. What does it mean for us to attribute their work done "while in church" to their Eco-Congregation, and the work they do whilst working alongside others in secular groups to "secular workers"? I'll be suggesting that there is a whole layer of Christian environmentalism which lies hidden away and that we need to appreciate the way in which a Christian community may serve as beacon or incubator for a wider range of environmental work and concern.

- Jeremy H. Kidwell and Michael Northcott, [“Temporality and Christian Environmental Activism”](https://jeremykidwell.info/publications/2018_temporality_activism/) in Greening of Religion: Hope in the Eye of the Storm, ed. Jonathan Leader, Cherry Hill Seminary Press, 2018, pp. 167-175.

In this article, we take up a question, first raised by Michael Northcott when he and I began working on our Ancestral Time project, as to whether the unique theologically formed understanding of time held by Christians might underwrite unique reactions to environmental challenges like climate change. There are a range of possible examples – the notion of the communion of saints and Christian eschatology to give two possible options – and we could see ways that these ideas provided unique theological options, but we wanted to know whether a Christian theology of time made a difference for Christian environmentalism among the general Christian (environmentally concerned) public. The short answer is "no". In general, we found it quite difficult to get any of our respondents to talk about time. In some cases respondents conveyed the same kind of "short-term emergency" thinking that is often present in secular environmental conversations. Others were (conversely) unconcerned with the passage of time, and noteably skeptical about human ability to predict the future in any way. In both of these two groupings, it was difficult to ascertain whether there was anything specifically theological about their response. There was little theological language used, even when asked through follow-up questions. What we concluded was that the general focus of our respondents was on climate change as a *human* problem, and a reluctance to leave the human frame in order to think about the distant future in any concrete way. I note in our article some ways that this maps onto the anthropology of time. The take-away for policymakers is that when seeking to find resonance with Christians on environmental issues, it is important to use temporal framings which map onto ordinary human lay-experience of those issues.

It's worth noting that my take-away from this study has also been that time is a terribly neglected concept in environmental philosophy and everyday Christian environmentalism. I'm working on a scholarly monograph which will take up this inquiry in the form of Christian moral and political philosophy: *Ecological Reconciliation and Time Reckoning* over the next 18 months. Stay tuned for more from me on how time *does* and *should* matter for the way we frame these issues.

### Also relevant are:

- An unpublished piece of data science research I have in preparation: ["Mapping Environmental Action"](http://mapenvcom.jeremykidwell.info/mapping_draft.html).

There's a ton of data science goodies in here for anyone who works with R of GIS data ([click here for a complete set of reproducible code and data on github](https://github.com/kidwellj/mapping_environmental_action)). I unpack how Eco-Congregations measure against several secular environmental groups in Scotland by location against key demographics. Notably, how they are concentrated in the various administrative regions of Scotland, how they are related to indices of multiple deprivation, and the urban/rural scale, and whether these groups are different in terms of their proximity to various kinds of wilderness and environmental conservation areas. Pretty charts, maps, and graphs galore!

- A forthcoming article presented for the International Studies Association, 
[Religion in Global Environmental Politics: Structuring Religious Environmentalism](https://jeremykidwell.info/presentations/201903_isa/) 

- Jeremy H. Kidwell, [“The historical roots of the ecological crisis”](https://jeremykidwell.info/publications/2018_oxford_handbook_crisis/) in OUP Handbook of Ecology and Bible, 2019

Here I take on the (in)famous article by Lynn White which suggests that Christianity is to blame for the environmental crisis (as it was in the 1960s) and look more broadly at the concept of "crisis" as it has been constructed. I argue that there are problematic framings of both "crisis" and "religion" at the heart of this debate and urge scholarls to look towards some more sophisticated framings of both concepts in engaging with climate change. Note: *You might sense a resonance here with my arguments above regarding how Christians react to apocalyptic framings of environmental problems...*

### I've presented in several fora:

- [Presentation on "Mobilising the Churches Around the Environment"](https://jeremykidwell.info/files/presentations/presentation-20190225-mobilising_churches.html) to a group of UK NGO executives and faith leaders (Feb 2019)
- ["“Mapping” Religious Communities in the UK: Borders, Boundaries and Big Data"](https://jeremykidwell.info/presentations/201809-basr/) to the British Association for the Study of Religion (Sep 2018)

For the curious, it's worth noting that, as I've been doing geospatial data science relating to Eco-Congregations and Eco-Churches, I've been shocked at the quality of data available on churches in the UK. I flesh out some of these problems in this presentation.

- ["The Scottish Communities Report"](https://jeremykidwell.info/files/presentations/presentation_20180605_sccs/presentation_20180605_sccs.html#1) to the Stop Climate Chaos (Climate Coalition) board of directors. (Jun 2018)

In this presentation, I distill some of my findings summarised above for a consortium of Scottish NGO and public policy groups (the English equivalent is the "Climate Coalition"). I was on the board for several years and this presentation came towards the end of my tenure as the board was trying to refine a focus on local communities as part of their work.

- ["Slow energy policy in a time of global emergencies"](https://jeremykidwell.info/presentations/201801_cambridge_energy/) to the Energy@Cambridge research initiative at Cambridge University (Jan 2018)

For this Cambridge paper, I provide a summary of some of our findings regarding Eco-Congregations above. As an enticement for the economists present for this presentation, I also did some additional analysis on how awards within the Scottish Government's Climate Challenge Fund map onto Eco-Congregations [(small repo with reproducible code here)](https://github.com/kidwellj/ccf_wordcloud) for R code I developed which can produce a word cloud representing key words included in text of these grant descriptions.

- ["Analysing the Development Trust Association Scotland footprint"](https://github.com/kidwellj/dtas_analysis) to the Development Trust association board of directors meeting (May 2018)

This work, which feeds into the Mapping Environmental Action study above, tested out the presence of DTAS groups against a variety of other kinds of feature in Scotland, particularly grocery shops and pubs. Click above for reproducible R code (though apologies that some of the underlying data is embargoed by Ordnance Survey, alas).
